@@ -1,6 +1,6 @@
 /*
  * liblognorm - a fast samples-based log normalization library
- * Copyright 2010-2017 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2010-2018 by Rainer Gerhards and Adiscon GmbH.
  *
  * Modified by Pavel Levshin (pavel@levshin.spb.ru) in 2013
  *
@@ -1388,15 +1388,17 @@ PARSER_DataForDisplay(CharTo)
 	struct data_CharTo *data = (struct data_CharTo*) pdata;
 	if(data->data_for_display == NULL) {
 		data->data_for_display = malloc(8+data->n_term_chars+2);
-		memcpy(data->data_for_display, "char-to{", 8);
-		size_t i, j;
-		for(j = 0, i = 8 ; j < data->n_term_chars ; ++j, ++i) {
-			data->data_for_display[i] = data->term_chars[j];
+		if(data->data_for_display != NULL) {
+			memcpy(data->data_for_display, "char-to{", 8);
+			size_t i, j;
+			for(j = 0, i = 8 ; j < data->n_term_chars ; ++j, ++i) {
+				data->data_for_display[i] = data->term_chars[j];
+			}
+			data->data_for_display[i++] = '}';
+			data->data_for_display[i] = '\0';
 		}
-		data->data_for_display[i++] = '}';
-		data->data_for_display[i] = '\0';
 	}
-	return data->data_for_display;
+	return (data->data_for_display == NULL ) ? "malloc error" : data->data_for_display;
 }
 PARSER_Destruct(CharTo)
 {
@@ -1846,7 +1848,8 @@ PARSER_Parse(CiscoInterfaceSpec)
 	json_object *json;
 	if(bHaveInterface) {
 		CHKN(json = json_object_new_string_len(c+idxInterface, lenInterface));
-		json_object_object_add_ex(*value, "interface", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
+		json_object_object_add_ex(*value, "interface", json,
+			JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
 	}
 	CHKN(json = json_object_new_string_len(c+idxIP, lenIP));
 	json_object_object_add_ex(*value, "ip", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
@@ -1854,13 +1857,16 @@ PARSER_Parse(CiscoInterfaceSpec)
 	json_object_object_add_ex(*value, "port", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
 	if(bHaveIP2) {
 		CHKN(json = json_object_new_string_len(c+idxIP2, lenIP2));
-		json_object_object_add_ex(*value, "ip2", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
+		json_object_object_add_ex(*value, "ip2", json,
+			JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
 		CHKN(json = json_object_new_string_len(c+idxPort2, lenPort2));
-		json_object_object_add_ex(*value, "port2", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
+		json_object_object_add_ex(*value, "port2", json,
+			JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
 	}
 	if(bHaveUser) {
 		CHKN(json = json_object_new_string_len(c+idxUser, lenUser));
-		json_object_object_add_ex(*value, "user", json, JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
+		json_object_object_add_ex(*value, "user", json,
+			JSON_C_OBJECT_ADD_KEY_IS_NEW|JSON_C_OBJECT_KEY_IS_CONSTANT);
 	}
 
 success: /* success, persist */
@@ -2210,6 +2216,7 @@ parseIPTablesNameValue(npb_t *const npb,
 {
 	int r = LN_WRONGPARSER;
 	size_t i = *offs;
+	char *name = NULL;
 
 	const size_t iName = i;
 	while(i < npb->strLen && isValidIPTablesNameChar(npb->str[i]))
@@ -2237,7 +2244,6 @@ parseIPTablesNameValue(npb_t *const npb,
 	if(valroot == NULL)
 		goto done;
 
-	char *name;
 	CHKN(name = malloc(lenName+1));
 	memcpy(name, npb->str+iName, lenName);
 	name[lenName] = '\0';
@@ -2248,8 +2254,8 @@ parseIPTablesNameValue(npb_t *const npb,
 		CHKN(json = json_object_new_string_len(npb->str+iVal, lenVal));
 	}
 	json_object_object_add(valroot, name, json);
-	free(name);
 done:
+	free(name);
 	return r;
 }
 
@@ -2394,6 +2400,7 @@ parseNameValue(npb_t *const npb,
 {
 	int r = LN_WRONGPARSER;
 	size_t i = *offs;
+	char *name = NULL;
 
 	const size_t iName = i;
 	while(i < npb->strLen && isValidNameChar(npb->str[i]))
@@ -2416,15 +2423,14 @@ parseNameValue(npb_t *const npb,
 	if(valroot == NULL)
 		goto done;
 
-	char *name;
 	CHKN(name = malloc(lenName+1));
 	memcpy(name, npb->str+iName, lenName);
 	name[lenName] = '\0';
 	json_object *json;
 	CHKN(json = json_object_new_string_len(npb->str+iVal, lenVal));
 	json_object_object_add(valroot, name, json);
-	free(name);
 done:
+	free(name);
 	return r;
 }
 
@@ -3321,6 +3327,7 @@ PARSER_Parse(String)
 			len = *parsed;
 		}
 		char *const cstr = strndup(npb->str+strt, len);
+		CHKN(cstr);
 		if(bHadEscape) {
 			/* need to post-process string... */
 			for(size_t j = 0 ; cstr[j] != '\0' ; j++) {
@@ -3435,6 +3442,9 @@ PARSER_Construct(String)
 		data->flags.esc_md = ST_ESC_NONE;
 	*pdata = data;
 done:
+	if(r != 0) {
+		free(data);
+	}
 	return r;
 }
 PARSER_Destruct(String)
