@@ -39,17 +39,17 @@
 // TODO #warning check how to handle "value" - does it need to be set to NULL?
 
 #define PARSERDEF_NO_DATA(parser) \
-	int ln_v2_parse##parser(npb_t *npb, size_t *offs, void *const, size_t *parsed, struct json_object **value);
+	int ln_v2_parse##parser(npb_t *npb, size_t *offs, void *const, size_t *parsed, struct json_object **value)
 
 #define PARSERDEF(parser) \
 	int ln_construct##parser(ln_ctx ctx, json_object *const json, void **pdata); \
 	int ln_v2_parse##parser(npb_t *npb, size_t *offs, void *const, size_t *parsed, struct json_object **value); \
-	void ln_destruct##parser(ln_ctx ctx, void *const pdata);
+	void ln_destruct##parser(ln_ctx ctx, void *const pdata)
 
-PARSERDEF_NO_DATA(RFC5424Date);
-PARSERDEF_NO_DATA(RFC3164Date);
-PARSERDEF_NO_DATA(Number);
-PARSERDEF_NO_DATA(Float);
+PARSERDEF(RFC5424Date);
+PARSERDEF(RFC3164Date);
+PARSERDEF(Number);
+PARSERDEF(Float);
 PARSERDEF(HexNumber);
 PARSERDEF_NO_DATA(KernelTimestamp);
 PARSERDEF_NO_DATA(Whitespace);
