@@ -142,7 +142,7 @@ ln_v1_parseFieldDescr(ln_ctx ctx, es_str_t *rule, es_size_t *bufOffs, es_str_t *
 
 	/* parse and process type (trailing whitespace must be trimmed) */
 	es_emptyStr(*str);
- 	size_t j = i;
+	size_t j = i;
 	/* scan for terminator */
 	while(j < lenBuf && buf[j] != ':' && buf[j] != '%')
 		++j;
@@ -239,27 +239,27 @@ ln_v1_parseFieldDescr(ln_ctx ctx, es_str_t *rule, es_size_t *bufOffs, es_str_t *
 		node->parser_data_destructor = regex_parser_data_destructor;
 	}
 #endif
-    else if (!es_strconstcmp(*str, "recursive")) {
-        node->parser = ln_parseRecursive;
-        constructor_fn = recursive_parser_data_constructor;
-        node->parser_data_destructor = recursive_parser_data_destructor;
-    } else if (!es_strconstcmp(*str, "descent")) {
-        node->parser = ln_parseRecursive;
-        constructor_fn = descent_parser_data_constructor;
-        node->parser_data_destructor = recursive_parser_data_destructor;
-    } else if (!es_strconstcmp(*str, "interpret")) {
-        node->parser = ln_parseInterpret;
-        constructor_fn = interpret_parser_data_constructor;
-        node->parser_data_destructor = interpret_parser_data_destructor;
-    } else if (!es_strconstcmp(*str, "suffixed")) {
-        node->parser = ln_parseSuffixed;
-        constructor_fn = suffixed_parser_data_constructor;
-        node->parser_data_destructor = suffixed_parser_data_destructor;
-    } else if (!es_strconstcmp(*str, "named_suffixed")) {
-        node->parser = ln_parseSuffixed;
-        constructor_fn = named_suffixed_parser_data_constructor;
-        node->parser_data_destructor = suffixed_parser_data_destructor;
-    } else {
+	else if (!es_strconstcmp(*str, "recursive")) {
+		node->parser = ln_parseRecursive;
+		constructor_fn = recursive_parser_data_constructor;
+		node->parser_data_destructor = recursive_parser_data_destructor;
+	} else if (!es_strconstcmp(*str, "descent")) {
+		node->parser = ln_parseRecursive;
+		constructor_fn = descent_parser_data_constructor;
+		node->parser_data_destructor = recursive_parser_data_destructor;
+	} else if (!es_strconstcmp(*str, "interpret")) {
+		node->parser = ln_parseInterpret;
+		constructor_fn = interpret_parser_data_constructor;
+		node->parser_data_destructor = interpret_parser_data_destructor;
+	} else if (!es_strconstcmp(*str, "suffixed")) {
+		node->parser = ln_parseSuffixed;
+		constructor_fn = suffixed_parser_data_constructor;
+		node->parser_data_destructor = suffixed_parser_data_destructor;
+	} else if (!es_strconstcmp(*str, "named_suffixed")) {
+		node->parser = ln_parseSuffixed;
+		constructor_fn = named_suffixed_parser_data_constructor;
+		node->parser_data_destructor = suffixed_parser_data_destructor;
+	} else {
 		cstr = es_str2cstr(*str, NULL);
 		ln_errprintf(ctx, 0, "invalid field type '%s'", cstr);
 		free(cstr);
@@ -489,7 +489,7 @@ addTagStrToBucket(ln_ctx ctx, es_str_t *tagname, struct json_object **tagBucket)
 {
 	int r = -1;
 	char *cstr;
-	struct json_object *tag; 
+	struct json_object *tag;
 
 	if(*tagBucket == NULL) {
 		CHKN(*tagBucket = json_object_new_array());
@@ -606,7 +606,8 @@ done:	return r;
  * @returns 0 on success, something else otherwise
  */
 static int
-getFieldName(ln_ctx __attribute__((unused)) ctx, const char *buf, es_size_t lenBuf, es_size_t *offs, es_str_t **strTag)
+getFieldName(ln_ctx __attribute__((unused)) ctx, const char *buf, es_size_t lenBuf, es_size_t *offs,
+es_str_t **strTag)
 {
 	int r = -1;
 	es_size_t i;
@@ -758,11 +759,11 @@ struct ln_v1_samp *
 ln_v1_processSamp(ln_ctx ctx, const char *buf, es_size_t lenBuf)
 {
 	struct ln_v1_samp *samp = NULL;
-    es_str_t *typeStr = NULL;
-    es_size_t offs;
+	es_str_t *typeStr = NULL;
+	es_size_t offs;
 
-    if(getLineType(buf, lenBuf, &offs, &typeStr) != 0)
-        goto done;
+	if(getLineType(buf, lenBuf, &offs, &typeStr) != 0)
+		goto done;
 
 	if(!es_strconstcmp(typeStr, "prefix")) {
 		if(getPrefix(buf, lenBuf, offs, &ctx->rulePrefix) != 0) goto done;
@@ -809,7 +810,7 @@ ln_v1_sampRead(ln_ctx ctx, FILE *const __restrict__ repo, int *const __restrict_
 		} else if(c == '\n') {
 			++ctx->conf_ln_nbr;
 			if(inParser) {
-				if(ln_sampChkRunawayRule(ctx, repo)) {
+				if(ln_sampChkRunawayRule(ctx, repo, NULL)) {
 					/* ignore previous rule */
 					inParser = 0;
 					i = 0;
@@ -818,7 +819,7 @@ ln_v1_sampRead(ln_ctx ctx, FILE *const __restrict__ repo, int *const __restrict_
 			if(!inParser && i != 0)
 				done = 1;
 		} else if(c == '#' && i == 0) {
-			ln_sampSkipCommentLine(ctx, repo);
+			ln_sampSkipCommentLine(ctx, repo, NULL);
 			i = 0; /* back to beginning */
 		} else {
 			if(c == '%')
