@@ -2,10 +2,11 @@
 # This file is part of the liblognorm project, released under ASL 2.0
 . $srcdir/exec.sh
 
-test_def $0 "dmac48 syntax"
-# we need to use a canned file, as we cannot easily reproduce the
-# malformed lines
-cp missing_line_ending.rb $(rulebase_file_name)
+test_def $0 "missing line ending"
+
+reset_rules
+add_rule 'version=2'
+add_rule_no_LF 'rule=:%field:mac48%'
 
 execute 'f0:f6:1c:5f:cc:a2'
 assert_output_json_eq '{"field": "f0:f6:1c:5f:cc:a2"}'
@@ -22,4 +23,4 @@ execute 'f0:f6:1c:xf:cc:a2'
 assert_output_json_eq '{ "originalmsg": "f0:f6:1c:xf:cc:a2", "unparsed-data": "f0:f6:1c:xf:cc:a2" }'
 
 
-#cleanup_tmp_files
+cleanup_tmp_files
